# Auth::Service::Authenticator

Utilizando a gem 'auth-service-authenticator', você irá plugar o serviço interno de autenticação em sua aplicação, sem necessidade de criação de um serviço de login.


## Installation

Adicione essa linha ao seu Gemfile:

```ruby
gem 'auth-service-authenticator'
```

na pasta `config` crie um arquivo com o nome `authenticator_config.yml` e adicione as chaves:
```ruby
url: URL_DO_SERVICO_DE_AUTENTICACAO
port: PORTA_DO_SERVICE_DE_AUTENTICACAO
```

Agora execute:
```sh
$ bundle install
```

## Como Utilizar

Utilize os metodos `authenticate` e `validate_token` e `logout`:
```ruby
  # Autentique o usuário fonecendo o email e senha
  response = Auth::Service::Authenticator::Manager.authenticate('EMAIL', 'SENHA')
  # Retornará um hash com o seguinte formato:
  {
    user: {
      "auth_token": "1KUg3T0BgEJ_D4W8CIT3sw",
      "user": {
        "email": "john@gmail.com",
        "first_name": "john",
        "last_name": "Due",
        "military_rank": 1,
        "registration": "999999-1",
        "cpf": "999999999-99"
      }
    }
  }

  # persista o token e utilize-o como uma sessão de usuário
  token = response[:user]["auth_token"]
  # salve o token ...

  # Em seus próximos requests, utilize o método abaixo para validar o token
  response = Auth::Service::Authenticator::Manager.validate_token(token)
  # Retornará um hash com o seguinte formato caso o token seja válido:
  {
    "user": {
      "email": "john@gmail.com",
      "first_name": "john",
      "last_name": "Due",
      "military_rank": 1,
      "registration": "999999-1",
      "cpf": "999999999-99"
    }
  }

  # caso o token seja inválido:
  {
    :error: "token invalido.",
    :status: "422",
    :message: "Unprocessable Entity"
  }

  # Caso o token seja válido, continue com sua aplicação normalmente.
  # Caso inválido, redirecione o usuário para página de login.

  # Logout do usuário
  response = Auth::Service::Authenticator::Manager.logout('TOKEN')
```

## Development

After checking out the repo, run `bin/setup` to install dependencies. Then, run `rake spec` to run the tests. You can also run `bin/console` for an interactive prompt that will allow you to experiment.

To install this gem onto your local machine, run `bundle exec rake install`. To release a new version, update the version number in `version.rb`, and then run `bundle exec rake release`, which will create a git tag for the version, push git commits and tags, and push the `.gem` file to [rubygems.org](https://rubygems.org).

## Contributing
Bug reports and pull requests are welcome on GitHub at https://github.com/brunojppb/auth-service-authenticator.

## License

The gem is available as open source under the terms of the [MIT License](http://opensource.org/licenses/MIT).
